<div>
  <h1>Thank you! Your account will be reviewed shortly</h1>
  <div>
      {% for message in messages %}
      <div>{{ message }}</div>
      {% endfor %}
  </div>
  <p>Right now, we're reviewing all accounts before allowing log in. If your account is approved, you'll receive an email with a login link. Thanks for your patience!</p>
</div>
