<h1>Hello!</h1>

<p>New account created on {{ site_name }}: {{ token.email }}</p>

<p><a href="https://{{ current_site.domain }}/admin/stagedoor/authtoken/">Approve here.</a></p>

<p>Thanks, from:</p>
<p>{{ site_name }}</p>
