# Generated by Django 5.2.1 on 2025-06-14 03:50

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("stagedoor", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="authtoken",
            name="approved",
            field=models.BooleanField(default=True),
        ),
    ]
